## Word Cloud from Messages

We'll extract out all messages sent by any participant, in chat under inspection and generate a word cloud for each of them.

Below is a demonstration of word cloud generated from a participant's messages sent to a group chat.

> Note: Only ASCII characters are supported as of now

![wordCloudOfMessagesByAnjan_VB](../plots/wordCloudOfMessagesByAnjan.png)
